0.9.9 API documentation: matrix_double3x2.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
matrix_double3x2.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef mat< 3, 2, double, defaultp > | dmat3x2
| 3 columns of 2 components matrix of double-precision floating-point numbers. More...

## Detailed Description

Core features

Definition in file matrix_double3x2.hpp.